@@ -75,7 +75,7 @@ class ResourceMeta(type):
 
 
 @six.add_metaclass(ResourceMeta)
-class Resource(object):
+class Resource(Serializer):
 
     """ Base JSON:API resource class."""
 
@@ -252,11 +252,11 @@ class Resource(object):
             filters["id__in"] = kwargs.get('ids')
 
         data = [
-            Serializer.dump_document(
+            cls.dump_document(
                 m,
                 fields=cls.fields_own,
                 fields_to_one=cls.fields_to_one,
-                fields_to_many=cls.fields_to_many
+                #fields_to_many=cls.fields_to_many
             )
             for m in model.objects.filter(**filters)
         ]
