@@ -1,4 +1,8 @@
 """ Serializer definition."""
+import json
+import datetime
+import decimal
+from django.db import models
 
 
 class Serializer(object):
@@ -19,6 +23,11 @@ class Serializer(object):
     server is unnecessary (e.g., read-only, transient entities), JSON API
     allows for omitting the "id" key.
 
+    Serializer:
+        1) Check custom serializer for field in Resource
+        2) Try to use predefined serializers for fields
+        3) Try convert to string
+
     """
 
     @classmethod
@@ -26,6 +35,8 @@ class Serializer(object):
                       fields_to_many=None):
         """ Get document for model_instance.
 
+        redefine dump rule for field x: def dump_document_x
+
         :param django.db.models.Model model_instance: model instance
         :param list of None fields: model_instance field to dump
         :return dict: document
@@ -35,11 +46,25 @@ class Serializer(object):
         fields_to_one = fields_to_one or {}
         fields_to_many = fields_to_many or {}
 
+        document = {}
         # apply rules for field serialization
-        document = {
-            name: getattr(model_instance, data["name"])
-            for name, data in fields.items()
-        }
+        for name, data in fields.items():
+            value = getattr(model_instance, data["name"])
+
+            field_serializer = getattr(
+                cls, "dump_document_{}".format(data["name"]), None)
+
+            if field_serializer is not None:
+                value = field_serializer(value)
+            else:
+                field = model_instance._meta.get_field(data["name"])
+                if isinstance(field, models.fields.files.FileField):
+                    value = cls.Meta.api.base_url + value.url
+                elif isinstance(field, models.CommaSeparatedIntegerField):
+                    value = [int(x) for x in value[1:-1].split(",")]
+
+            document[name] = value
+
         if fields_to_one or fields_to_many:
             document["links"] = {}
 
@@ -66,22 +91,26 @@ class Serializer(object):
 
         pass
 
-    @classmethod
-    def get_id(cls, model_instance):
-        """ Get id for given model_instance.
 
-        :param django.db.models.Model model_instance: model instance
-        :return id: model id (primary key)
+class DatetimeDecimalEncoder(json.JSONEncoder):
+
+    """ Encoder for datetime and decimal serialization.
+
+    Usage: json.dumps(object, cls=DatetimeDecimalEncoder)
+    NOTE: _iterencode does not work
+
+    """
+
+    def default(self, o):
+        """ Encode JSON.
+
+        :return str: A JSON encoded string
 
         """
-        return model_instance.pk
+        if isinstance(o, (datetime.datetime, datetime.date, datetime.time)):
+            return o.isoformat()
 
-    @classmethod
-    def get_fields(cls, model):
-        """ Get fields for given model.
+        if isinstance(o, decimal.Decimal):
+            return float(o)
 
-        :param django.db.models.Model model: model instance
-        :return list fields: model fields
-
-        """
-        return model._meta.fields + model._meta.many_to_many
+        return json.JSONEncoder.default(self, o)
